pyxmpp2.streamevents.StreamEvent

Package pyxmpp2 :: Module streamevents :: Class StreamEvent |
[hide private]

# Class StreamEvent

Base class for all stream events.

Nested Classes | [hide private]
Inherited from `mainloop.interfaces.Event`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `mainloop.interfaces.Event`: `__unicode__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| stream = `None` hash(x)
Inherited from `mainloop.interfaces.Event`: `__abstractmethods__` Inherited from `mainloop.interfaces.Event` (private): `_abc_cache`, `_abc_negative_cache`, `_abc_negative_cache_version`, `_abc_registry`

Properties | [hide private]
Inherited from `object`: `__class__`